@@ -2,8 +2,10 @@ use strict;
 use warnings;
 package A1z::HTML5::Template;
 
+# ABSTRACT: turns baubles into trinkets
 
-our $VERSION = '0.05';
+
+our $VERSION = '0.07';
 
 
 
@@ -74,6 +76,8 @@ sub math1
 	return qq{\n$out\n};
 }
 
+
+
 # begin timestable 
 sub timestable 
 {	
@@ -1150,9 +1154,6 @@ $in{-userjquery}
 # end body 
 
 
-
-
-
 sub create_accordion 
 {
 	my $out; 
@@ -1667,11 +1668,11 @@ __END__
 
 =head1 NAME
 
-A1z::HTML5::Template
+A1z::HTML5::Template - turns baubles into trinkets
 
 =head1 VERSION
 
-version 0.05
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -1679,18 +1680,18 @@ Quick summary of what the module does.
 
 Perhaps a little code snippet.
 
-    use HTML5::Template;
+    use A1z::HTML5::Template;
 
-    my $foo = HTML5::Template->new();
+    my $foo = A1z::HTML5::Template->new();
     ...
 
 =head1 NAME
 
-HTML5::Template - The great new HTML5::Template!
+A1z::HTML5::Template
 
 =head1 VERSION
 
-Version 0.05
+Version 0.07
 
 =head1 EXPORT
 
@@ -1703,24 +1704,23 @@ body_accordion end_body end_html
 
 =head2 new
 
+   use A1z::HTML5::Template;
+   my $foo = A1z::HTML5::Template->new();
+
 =head2 math1
 
 Usage
-math1(num1, num2);
+
+$foo->math1(num1, num2);
+
+=head1 Times Table
+	usage $foo->timestable("Number");
 
 =head1 Usage
 
 	my $h = Template->new();
 	say $h->body_accordion( $h->open_file("C:/Users/user/public/app/open_file_example.txt", 'Type', 'Header') ); 
 
-=head1 SUPPORT
-
-Support via email only: <perl-cpan at bislinks.com>
-
-=head1 AUTHOR
-
-Copyright 2012 Anonymous.
-
 =head1 AUTHOR
 
 Sudheer Murthy, C<< <pause at a1z.us> >>
@@ -1735,7 +1735,7 @@ automatically be notified of progress on your bug as I make changes.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc HTML5::Template
+    perldoc A1z::HTML5::Template
 
 You can also look for information at:
 
